Struct imgui::ImFontAtlas [−][src]
#[repr(C)]pub struct ImFontAtlas<'a> { /* fields omitted */ }
A handle to imgui's font manager.
Methods
impl<'a> ImFontAtlas<'a>[src]
impl<'a> ImFontAtlas<'a>pub fn add_default_font(&mut self) -> ImFont[src]
pub fn add_default_font(&mut self) -> ImFontAdds the default font to the font set.
pub fn add_default_font_with_config(&mut self, config: ImFontConfig) -> ImFont[src]
pub fn add_default_font_with_config(&mut self, config: ImFontConfig) -> ImFontAdds the default fnt to the font set with the given configuration.
pub fn add_font(
&mut self,
data: &[u8],
size: f32,
range: &FontGlyphRange
) -> ImFont[src]
pub fn add_font(
&mut self,
data: &[u8],
size: f32,
range: &FontGlyphRange
) -> ImFontAdds a custom font to the font set.
pub fn add_font_with_config(
&mut self,
data: &[u8],
config: ImFontConfig,
range: &FontGlyphRange
) -> ImFont[src]
pub fn add_font_with_config(
&mut self,
data: &[u8],
config: ImFontConfig,
range: &FontGlyphRange
) -> ImFontAdds a custom font to the font set with the given configuration. A font size must be set in the configuration.
Panics
If no font size is set for the configuration.
pub fn font_count(&self) -> usize[src]
pub fn font_count(&self) -> usizeThe number of fonts currently registered in the atlas.
pub fn index_font(&mut self, index: usize) -> ImFont[src]
pub fn index_font(&mut self, index: usize) -> ImFontpub fn clear(&mut self)[src]
pub fn clear(&mut self)Clears all fonts associated with this texture atlas.
pub fn texture_id(&self) -> usize[src]
pub fn texture_id(&self) -> usizepub fn set_texture_id(&mut self, value: usize)[src]
pub fn set_texture_id(&mut self, value: usize)Auto Trait Implementations
impl<'a> !Send for ImFontAtlas<'a>
impl<'a> !Send for ImFontAtlas<'a>impl<'a> !Sync for ImFontAtlas<'a>
impl<'a> !Sync for ImFontAtlas<'a>