Struct imgui::ImFontConfig [−][src]
pub struct ImFontConfig { /* fields omitted */ }A builder for the configuration for a font.
Methods
impl ImFontConfig[src]
impl ImFontConfigpub fn new() -> ImFontConfig[src]
pub fn new() -> ImFontConfigpub fn size_pixels(self, size_pixels: f32) -> ImFontConfig[src]
pub fn size_pixels(self, size_pixels: f32) -> ImFontConfigpub fn oversample_h(self, oversample_h: u32) -> ImFontConfig[src]
pub fn oversample_h(self, oversample_h: u32) -> ImFontConfigpub fn oversample_v(self, oversample_v: u32) -> ImFontConfig[src]
pub fn oversample_v(self, oversample_v: u32) -> ImFontConfigpub fn pixel_snap_h(self, pixel_snap_h: bool) -> ImFontConfig[src]
pub fn pixel_snap_h(self, pixel_snap_h: bool) -> ImFontConfigpub fn glyph_extra_spacing<I: Into<ImVec2>>(
self,
extra_spacing: I
) -> ImFontConfig[src]
pub fn glyph_extra_spacing<I: Into<ImVec2>>(
self,
extra_spacing: I
) -> ImFontConfigpub fn glyph_offset<I: Into<ImVec2>>(self, glyph_offset: I) -> ImFontConfig[src]
pub fn glyph_offset<I: Into<ImVec2>>(self, glyph_offset: I) -> ImFontConfigpub fn merge_mode(self, merge_mode: bool) -> ImFontConfig[src]
pub fn merge_mode(self, merge_mode: bool) -> ImFontConfigpub fn rasterizer_multiply(self, rasterizer_multiply: f32) -> ImFontConfig[src]
pub fn rasterizer_multiply(self, rasterizer_multiply: f32) -> ImFontConfigpub fn add_font<'a>(
self,
atlas: &'a mut ImFontAtlas<'a>,
data: &[u8],
range: &FontGlyphRange
) -> ImFont<'a>[src]
pub fn add_font<'a>(
self,
atlas: &'a mut ImFontAtlas<'a>,
data: &[u8],
range: &FontGlyphRange
) -> ImFont<'a>Adds a custom font to the font set with the given configuration. A font size must be set in the configuration.
Panics
If no font size is set for the configuration.
pub fn add_default_font<'a>(self, atlas: &'a mut ImFontAtlas<'a>) -> ImFont<'a>[src]
pub fn add_default_font<'a>(self, atlas: &'a mut ImFontAtlas<'a>) -> ImFont<'a>Adds the default font to a given atlas using this configuration.