Struct imgui::MultiColorStackToken [−][src]
pub struct MultiColorStackToken { /* fields omitted */ }Expand description
Tracks one or more changes pushed to the color stack that must be popped by calling .pop()
pub struct MultiColorStackToken { /* fields omitted */ }Tracks one or more changes pushed to the color stack that must be popped by calling .pop()