Struct imgui::MultiStyleStackToken [−][src]
pub struct MultiStyleStackToken { /* fields omitted */ }Expand description
Tracks one or more changes pushed to the style stack that must be popped by calling .pop()
pub struct MultiStyleStackToken { /* fields omitted */ }Tracks one or more changes pushed to the style stack that must be popped by calling .pop()