pub struct PopupModal<'ui, 'p, Label> { /* private fields */ }Expand description
Create a modal pop-up.
Example
if ui.button("Show modal") {
ui.open_popup("modal");
}
if let Some(_token) = ui.begin_modal_popup("modal") {
ui.text("Content of my modal");
if ui.button("OK") {
ui.close_current_popup();
}
};Implementations
Sourceimpl<'ui, 'p, Label: AsRef<str>> PopupModal<'ui, 'p, Label>
impl<'ui, 'p, Label: AsRef<str>> PopupModal<'ui, 'p, Label>
pub fn new(ui: &'ui Ui, label: Label) -> Self
👎Deprecated since 0.9.0: Use
ui.modal_popup_config(...) insteadSourcepub fn opened(self, opened: &'p mut bool) -> Self
pub fn opened(self, opened: &'p mut bool) -> Self
Pass a mutable boolean which will be updated to refer to the current “open” state of the modal.
pub fn flags(self, flags: WindowFlags) -> Self
pub fn title_bar(self, value: bool) -> Self
pub fn resizable(self, value: bool) -> Self
pub fn movable(self, value: bool) -> Self
pub fn scroll_bar(self, value: bool) -> Self
pub fn scrollable(self, value: bool) -> Self
pub fn collapsible(self, value: bool) -> Self
pub fn always_auto_resize(self, value: bool) -> Self
pub fn save_settings(self, value: bool) -> Self
pub fn inputs(self, value: bool) -> Self
pub fn horizontal_scrollbar(self, value: bool) -> Self
pub fn no_focus_on_appearing(self, value: bool) -> Self
pub fn no_bring_to_front_on_focus(self, value: bool) -> Self
pub fn always_vertical_scrollbar(self, value: bool) -> Self
pub fn always_horizontal_scrollbar(self, value: bool) -> Self
pub fn always_use_window_padding(self, value: bool) -> Self
Sourcepub fn build<T, F: FnOnce() -> T>(self, f: F) -> Option<T>
pub fn build<T, F: FnOnce() -> T>(self, f: F) -> Option<T>
Consume and draw the PopupModal. Returns the result of the closure, if it is called.
Sourcepub fn begin_popup(self) -> Option<PopupToken<'ui>>
pub fn begin_popup(self) -> Option<PopupToken<'ui>>
Consume and draw the PopupModal. Construct a popup that can have any kind of content.
This should be called per frame, whereas Ui::open_popup
should be called once when you want to actual create the popup.