Struct imgui::StyleStackToken [−][src]
pub struct StyleStackToken<'a>(_);Expand description
Tracks a style pushed to the style stack that can be popped by calling .end()
or by dropping.
pub struct StyleStackToken<'a>(_);Tracks a style pushed to the style stack that can be popped by calling .end()
or by dropping.