Struct imgui::CollapsingHeader [−][src]
pub struct CollapsingHeader<T> { /* fields omitted */ }Expand description
Builder for a collapsing header widget
Implementations
Constructs a new collapsing header builder
Replaces all current settings with the given flags.
Enables/disables allowing the collapsing header to overlap subsequent widgets.
Disabled by default.
Sets the default open state for the collapsing header.
Collapsing headers are closed by default.
Only open when the collapsing header is double-clicked.
Disabled by default.
Only open when clicking the arrow part of the collapsing header.
Disabled by default.
Enable/disables leaf mode (no collapsing, no arrow).
Disabled by default.
Display a bullet instead of arrow.
Disabled by default.
Use frame_padding to vertically align text baseline to regular widget height.
Disabled by default.
Begins the collapsing header.
Returns true if the collapsing header is open and content should be rendered.
This is the same as build but is provided for consistent naming.
Begins the collapsing header.
Returns true if the collapsing header is open and content should be rendered.
This is the same as build_with_close_button but is provided for consistent naming.
Builds the collapsing header.
Returns true if the collapsing header is open and content should be rendered.
Builds the collapsing header, and adds an additional close button that changes the value of the given mutable reference when clicked.
Returns true if the collapsing header is open and content should be rendered.